@@ -12,11 +12,11 @@ async def some_handler(context, container):
 
 
 async def add_plugin(context, app_container):
-    await app_container.ticket_service().worker.add_new_plugin(context.request.json.get("filename"))
+    await app_container.ticket_service().worker.add_new_middleware(context.request.json.get("filename"))
     # mg = app_container.plugin_manager()
     # # await app_container.store().get_all()
-    # await mg.add_new_plugin(context.request.json.get("filename"))
-    # await app_container.ticket_service().emmit_event(StoreUpdateEvent("plugins", mg.available_plugins))
+    # await mg.add_new_middleware(context.request.json.get("filename"))
+    # await app_container.ticket_service().emmit_event(StoreUpdateEvent("plugins", mg.available_middlewares))
     # await app_container.ticket_service().emmit_event(CloseChargeAeEvent())
     return {}
 
