@@ -3,6 +3,15 @@ from typing import Any
 from web_foundation.kernel import IMessage
 
 
+class StoredPluginsUpdate(IMessage):
+    message_type = "stored_plugin_update"
+    filename: str
+
+    def __init__(self, filename: str):
+        super().__init__()
+        self.filename = filename
+
+
 class StoreUpdateEvent(IMessage):
     message_type = "store_update"
 
@@ -11,6 +20,5 @@ class StoreUpdateEvent(IMessage):
         self.key = key
         self.value = value
 
-
     def __str__(self):
-        return f"StoreUpdateEvent({self.key})"
\ No newline at end of file
+        return f"{self.__class__.__name__}({self.key})"
