@@ -2,6 +2,7 @@ from typing import Type
 
 from sanic import Request
 from pydantic import ValidationError as PdValidationError, BaseModel as PdModel
+from sanic.exceptions import BadRequest
 
 from web_foundation.app.errors.application.application import ValidationError
 
@@ -9,8 +10,14 @@ from web_foundation.app.errors.application.application import ValidationError
 def validate_dto(dto_cls: Type[PdModel] | None,request: Request) -> PdModel | None:
     if not dto_cls:
         return None
+    if "json" in request.content_type:
+        data = request.json
+    elif "form" in request.content_type:
+        data = {key: value[0] for key, value in request.form.items()}
+    else:
+        raise BadRequest("Incorrect content type")
     try:
-        dto = dto_cls(**request.json)
+        dto = dto_cls(**data)
         return dto
     except PdValidationError as ex:
         failed_fields = ex.errors()
