@@ -10,7 +10,7 @@ from pydantic import BaseModel as PdModel
 from sanic import Request, json, HTTPResponse
 
 from web_foundation.app.app import AppContainer
-from web_foundation.app.infrastructure.plugins.manager import PluginsManager
+from web_foundation.app.infrastructure.mdw_manager import ApiMiddlewareManager
 from web_foundation.utils.validation import validate_dto
 
 DtoType = TypeVar("DtoType", bound=PdModel)
@@ -46,7 +46,7 @@ async def protect(request: Request) -> ProtectIdentity | None:
 
 def chain(protector: Protector = protect,
           in_struct: Type[PdModel] | None = None,
-          plugin_manager: PluginsManager = None,
+          plugin_manager: ApiMiddlewareManager = None,
           validation_fnc: DtoValidator = validate_dto,
           response_fabric: Callable[[TypeJSON], HTTPResponse] = json,
           ):
@@ -62,8 +62,8 @@ def chain(protector: Protector = protect,
                 validated = None
             incoming = InputContext(req, validated, prot_identity, kwargs)
             if plugin_manager:
-                plugins = await plugin_manager.find_plugin_by_target(target.__name__)
-                for plugin in await plugin_manager.find_plugin_by_target(target.__name__):
+                plugins = await plugin_manager.find_middleware_by_target(target.__name__)
+                for plugin in await plugin_manager.find_middleware_by_target(target.__name__):
                     await plugin.exec_before(context=incoming, container=container)
                     # if plugin.override:
                     #     ret_val = await plugin.exec_override(context=incoming, container=container)
